@@ -1,6 +1,6 @@
 package Astro::Constants;
-# ABSTRACT: this library provides physical constants for use in Astronomy
-$Astro::Constants::VERSION = '0.12';
+# ABSTRACT: This library provides physical constants for use in Physics and Astronomy based on values from CODATA2014.
+$Astro::Constants::VERSION = '0.13';
 use 5.006;
 use strict;
 use warnings;
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-Astro::Constants - this library provides physical constants for use in Astronomy
+Astro::Constants - This library provides physical constants for use in Physics and Astronomy based on values from CODATA2014.
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -138,7 +138,7 @@ Planck's constant /2pi
 This constant is also available using the short name C<$A_hbar>
 as well as the alternate name C<HBAR> (imported using the :alternate tag for backwards compatibility)
 
-=head2 ELECTRON_CHARGE
+=head2 CHARGE_ELEMENTARY
 
     1.6021766208e-19	MKS
     4.8032046729e-10	CGS
@@ -146,7 +146,7 @@ as well as the alternate name C<HBAR> (imported using the :alternate tag for bac
 electron charge (defined positive)
 
 This constant is also available using the short name C<$A_e>
-as well as the alternate name C<CHARGE_ELEMENTARY> (imported using the :alternate tag for backwards compatibility)
+as well as the alternate name C<ELECTRON_CHARGE> (imported using the :alternate tag for backwards compatibility)
 
 =head2 STEFAN_BOLTZMANN
 
@@ -603,6 +603,22 @@ Bohr radius
 This constant is also available using the short name C<$A_a0>
 as well as the alternate name C<BOHR_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
+=head2 RADIUS_JUPITER
+
+    69_911_000	MKS
+
+Volumetric mean radius of Jupiter
+
+This constant is also available using the short name C<$A_rjup>
+
+=head2 MASS_JUPITER
+
+    1.89819e27	MKS
+
+mass of Jupiter
+
+This constant is also available using the short name C<$A_mjup>
+
 =head2 pretty
 
 This is a helper function that rounds a value or list of values to 5 significant figures.
@@ -694,6 +710,10 @@ L<Astronomical Almanac|http://asa.usno.navy.mil>
 
 =item *
 
+L<IAU 2015 Resolution B3|http://iopscience.iop.org/article/10.3847/0004-6256/152/2/41/meta>
+
+=item *
+
 L<Neil Bower's review on providing read-only values|http://neilb.org/reviews/constants.html>
 
 =item *
@@ -818,7 +838,7 @@ Boyd Duffee <duffee@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Boyd Duffee.
+This software is copyright (c) 2018 by Boyd Duffee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
