@@ -14,7 +14,6 @@ use XML::LibXML;
 
 my ($tagname, );
 my $dzil_methodtag = q{=method};
-my $ALTERNATES_IN_LONG_TAG = 0;
 
 my $xml = XML::LibXML->load_xml(location => 'data/PhysicalConstants.xml');
 
@@ -59,8 +58,12 @@ for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
 			next unless $alternate =~ /\S/;
 
 			push @{$tagname->{alternates}}, $alternate;
-			push @{$tagname->{long}}, $alternate if $ALTERNATES_IN_LONG_TAG;
-			# if alternateName tag has type="deprecated", put in $tagname->{deprecated} not $tagname->{long}
+			if ($node->hasAttribute('type') && $node->getAttribute('type') eq 'deprecated') {
+				push @{$tagname->{deprecated}}, $alternate;
+			}
+			else {
+				push @{$tagname->{long}}, $alternate;
+			}
 			push @alternates, $alternate;
 
 			write_constant($mks_fh, ($values->{mks} || $values->{value}), $alternate) 
@@ -107,7 +110,7 @@ sub write_module_header {
 
 	print $fh <<HEADER;
 package $name;
-# ABSTRACT: this library provides physical constants for use in Astronomy
+# ABSTRACT: This library provides physical constants for use in Physics and Astronomy based on values from CODATA2014.
 
 use 5.006;
 use strict;
@@ -119,6 +122,24 @@ HEADER
 	else {
 		print $fh "use base qw/Exporter/;\n\n";
 	}
+	if ($name eq 'Astro::Constants::CGS') {
+		print $fh qq(warn "use of $name is deprecated and will be removed from the package in version 0.15";\n);
+		print $fh qq(warn "write new code to use Astro::Constants::MKS instead";\n\n);
+		print $fh <<"NOTICE";
+warn "use of $name is deprecated and will be removed from the package in version 0.15";
+warn "write new code to use Astro::Constants::MKS instead";
+
+=head1 NOTICE OF DEPRECATION
+
+This module is now deprecated and will be removed from the package in version 0.15.
+Write new code to use L<Astro::Constants> or check the documentation.
+The IAU stopped using cgs units last century, so it's about time this module was archived.
+
+=cut
+
+
+NOTICE
+	}
 }
 
 sub write_module_footer {
@@ -317,6 +338,7 @@ the documentation.  Use C<perldoc Astro::Constants> for that information.
 * L<Perl Data Language|PDL>
 * L<NIST|http://physics.nist.gov>
 * L<Astronomical Almanac|http://asa.usno.navy.mil>
+* L<IAU 2015 Resolution B3|http://iopscience.iop.org/article/10.3847/0004-6256/152/2/41/meta>
 * L<Neil Bower's review on providing read-only values|http://neilb.org/reviews/constants.html>
 * L<Test::Number::Delta>
 * L<Test::Deep::NumberTolerant> for testing values within objects
